.. :changelog:

v0.4.0 (2025-03-31)
-------------------

* Add ability to specify a particular column in a transmission data file using ``trans_colname`` keyword (#33)

New Filter Curves
^^^^^^^^^^^^^^^^^

* JWST NIRISS & NIRCam double-wides
* Panstarrs (#29, h/t @awe2)
* BASS & MZLS (h/t @moustakas)
* ROMAN pre-flight as different columns for each chip along with a default signal weighted chip average (#33 h/t C. Zucker)
* SPHEREx post-flight, one transmission file for each band, with channels as different columns (h/t Matt Ashby)


Updated Filter Curves
^^^^^^^^^^^^^^^^^^^^^

* Gaia curves updated to EDR3
* VISTA updates (h/t @stevet40 and @silvanfischbacher)
* Updated NIRCam curves (dated May 2024)



`Full Changelog <https://github.com/bd-j/sedpy/compare/v0.3.2...v0.4.0>`_